options ls=78 ps=84 nocenter;

/* rerun: 4-97 for ema second round

   program agg1 -- aggregate and average earnings across years
   produces 6-year average earnings and variance

   NAGG182 -- POOLED DATA SET FOR 82-83

   MAKES SAVE.FOUR82

   written 6.2.96  */


* libname save '/bbkinghome/sschaner/Angrist Work/Web Papers/Angrist_1998/SAS data/';
* libname save '/data/angrist/asvab/save';


data one;
set save.ssaone;

if ((transyy ge 79) and (edgrp ne 10) and (2<=afqtgrp<=6)
   and (year=83));


sigma2=(stdvar**2)/SAMcount;

if ((earnvar ne .) and (sigma2 ne .));

***> correlation sequence;

data /*d80 d81 d82*/ d83;
set one;

 if year=83 then output d83;


data d83; set d83; y83=earnvar; s83=sigma2; n83=SAMcount; p83=POPcount;
   matchvar=_n_;
   keep y83 s83 n83 p83 matchvar dnwhite edgrp dobyy transyy afqtgrp dvet;

data wide;
 set d83;
 
proc sort data=wide; by dnwhite;

proc corr data=wide outp=corrmtx;
var y83;
by dnwhite;

proc print data=corrmtx;
run;

data corrmtx;
  set corrmtx;
  if _type_ eq 'CORR';
  if (_name_ eq 'Y83' | _name_ eq 'y83') then year=83;
  keep dnwhite year y83;
  run;
  
proc print data=corrmtx;
title 'corr matrix by race for 83 earnings';

**************** WHITES *******************;

 data wide_w; set wide; if dnwhite=0;
 data mtx_w; set corrmtx; if dnwhite=0;

 proc iml;

 use wide_w;
 read all var{ y83} into Y;
 read all var{ s83} into S;
 read all var{ n83} into P;
 close wide_w;

 use mtx_w;
 read all var{ y83} into corr;
 close mtx_w;

 s=s##.5;

 nobs=nrow(y);

 mean=j(nobs,1,0);
 rs=j(1,1,0);
 covmtx=j(1,1,0);
 avgvar=j(nobs,1,0);
 weights=j(1,1,0);

 /* loop to compute average earnings and variance */

 do i=1 to nobs;

   weights=P[i,]/P[i,+];
   mean[i]=weights*Y[i,]`;

   rs=S[i,]`;
   covmtx=diag(rs)*corr*diag(rs);

   avgvar[i]=weights*covmtx*weights`;

   end;

   results = mean||avgvar;
   varnames={'pooly' 'poolvar'};

create threew from results [colname=varnames];
append from results;


************ NONWHITES ******************;

 data wide_n; set wide; if dnwhite=1;
 data mtx_n; set corrmtx; if dnwhite=1;

 proc iml;

 use wide_n;
 read all var{ y83} into Y;
 read all var{ s83} into S;
 read all var{ n83} into P;
 close wide_n;

 use mtx_n;
 read all var{ y83} into corr;
 close mtx_n;

 s=s##.5;

 nobs=nrow(y);

 mean=j(nobs,1,0);
 rs=j(1,1,0);
 covmtx=j(1,1,0);
 avgvar=j(nobs,1,0);
 weights=j(1,1,0);

 /* loop to compute average earnings and variance */

 do i=1 to nobs;

   weights=P[i,]/P[i,+];
   mean[i]=weights*Y[i,]`;

   rs=S[i,]`;
   covmtx=diag(rs)*corr*diag(rs);

   avgvar[i]=weights*covmtx*weights`;

   end;

   results = mean||avgvar;
   varnames={'pooly' 'poolvar'};

create threen from results [colname=varnames];
append from results;


/* put average and variance back on wide ds */

data three;
 set threew(in=inw) threen;
 if inw=1 then dnwhite=0; else dnwhite=1;
 matchvar=_n_;

proc sort data=wide; by matchvar;

data save.four82_sgs;
 merge wide three;
 by matchvar;

 poolsam=n83;
 poolpop=p83;

 poolsig2=poolvar*poolsam;     **> same as orig. progs;

proc sort data=save.four82_sgs;  by dnwhite;

proc means data=save.four82_sgs;
by dnwhite;
run;
