options ls=78 ps=84 nocenter;

/* rerun: 4-97 for ema second round

   program agg1 -- aggregate and average earnings across years
   produces 6-year average earnings and variance

   NAGG184 -- POOLED DATA SET FOR 84-87

   MAKES SAVE.FOUR84

   written 23.1.96  */


* libname save '/bbkinghome/sschaner/Angrist Work/Web Papers/Angrist_1998/SAS data/';
* libname save '/data/angrist/asvab/save';


data one;
set save.ssaone;

if ((transyy ge 79) and (edgrp ne 10) and (2<=afqtgrp<=6)
   and (82<=year<=87));

   year=year+4;     ** maps 84->88, 85->89, 86->90, 87->91;

sigma2=(stdvar**2)/SAMcount;

if ((earnvar ne .) and (sigma2 ne .));

***> correlation sequence;

data d86 d87 d88 d89 d90 d91;
set one;

 if year=86 then output d86;
 if year=87 then output d87;
 if year=88 then output d88;
 if year=89 then output d89;
 if year=90 then output d90;
 if year=91 then output d91;

data d86; set d86; y86=earnvar; s86=sigma2; n86=SAMcount; p86=POPcount;
   matchvar=_n_;
   keep dnwhite edgrp dobyy transyy afqtgrp dvet y86 s86 n86 p86 matchvar;
data d87; set d87; y87=earnvar; s87=sigma2; n87=SAMcount; p87=POPcount;
   matchvar=_n_;
   keep y87 s87 n87 p87 matchvar;
data d88; set d88; y88=earnvar; s88=sigma2; n88=SAMcount; p88=POPcount;
   matchvar=_n_;
   keep y88 s88 n88 p88 matchvar;
data d89; set d89; y89=earnvar; s89=sigma2; n89=SAMcount; p89=POPcount;
   matchvar=_n_;
   keep y89 s89 n89 p89 matchvar;
data d90; set d90; y90=earnvar; s90=sigma2; n90=SAMcount; p90=POPcount;
   matchvar=_n_;
   keep y90 s90 n90 p90 matchvar;
data d91; set d91; y91=earnvar; s91=sigma2; n91=SAMcount; p91=POPcount;
   matchvar=_n_;
   keep y91 s91 n91 p91 matchvar;

data wide;
 merge d86 d87 d88 d89 d90 d91;
 by matchvar;


proc corr data=wide outp=corrmtx;
var y88-y91;
by dnwhite;

data corrmtx;
  set corrmtx;
  if _type_ eq 'CORR';
  if _name_ eq 'Y86' then year=86;
  else  if _name_ eq 'Y87' then year=87;
  else  if _name_ eq 'Y88' then year=88;
  else  if _name_ eq 'Y89' then year=89;
  else  if _name_ eq 'Y90' then year=90;
  else  if _name_ eq 'Y91' then year=91;
  keep dnwhite year y86-y91;

proc print data=corrmtx;
title 'corr matrix by race for 86-91 earnings';

**************** WHITES *******************;

 data wide_w; set wide; if dnwhite=0;
 data mtx_w; set corrmtx; if dnwhite=0;

 proc iml;

 use wide_w;
 read all var{  y88 y89 y90 y91} into Y;
 read all var{  s88 s89 s90 s91} into S;
 read all var{  n88 n89 n90 n91} into P;
 close wide_w;

 use mtx_w;
 read all var{  y88 y89 y90 y91} into corr;
 close mtx_w;

 s=s##.5;

 nobs=nrow(y);

 mean=j(nobs,1,0);
 rs=j(1,4,0);
 covmtx=j(4,4,0);
 avgvar=j(nobs,1,0);
 weights=j(1,4,0);

 /* loop to compute average earnings and variance */

 do i=1 to nobs;

   weights=P[i,]/P[i,+];
   mean[i]=weights*Y[i,]`;

   rs=S[i,]`;
   covmtx=diag(rs)*corr*diag(rs);

   avgvar[i]=weights*covmtx*weights`;

   end;

   results = mean||avgvar;
   varnames={'pooly' 'poolvar'};

create threew from results [colname=varnames];
append from results;


************ NONWHITES ******************;

 data wide_n; set wide; if dnwhite=1;
 data mtx_n; set corrmtx; if dnwhite=1;

 proc iml;

 use wide_n;
 read all var{  y88 y89 y90 y91} into Y;
 read all var{  s88 s89 s90 s91} into S;
 read all var{  n88 n89 n90 n91} into P;
 close wide_n;

 use mtx_n;
 read all var{  y88 y89 y90 y91} into corr;
 close mtx_n;

 s=s##.5;

 nobs=nrow(y);

 mean=j(nobs,1,0);
 rs=j(1,4,0);
 covmtx=j(4,4,0);
 avgvar=j(nobs,1,0);
 weights=j(1,4,0);

 /* loop to compute average earnings and variance */

 do i=1 to nobs;

   weights=P[i,]/P[i,+];
   mean[i]=weights*Y[i,]`;

   rs=S[i,]`;
   covmtx=diag(rs)*corr*diag(rs);

   avgvar[i]=weights*covmtx*weights`;

   end;

   results = mean||avgvar;
   varnames={'pooly' 'poolvar'};

create threen from results [colname=varnames];
append from results;


/* put average and variance back on wide ds */

data three;
 set threew(in=inw) threen;
 if inw=1 then dnwhite=0; else dnwhite=1;
 matchvar=_n_;


data save.four84;
 merge wide three;
 by matchvar;

 poolsam=n88+n89+n90+n91;
 poolpop=p88+p89+p90+p91;

 poolsig2=poolvar*poolsam;     **> same as orig. progs;

proc means data=save.four84;
by dnwhite;
run;





